==> rutorrent-3.9.tar.gz: ruTorrent-3.9/lang/es.js <==
﻿/*
 * Spanish language file.
 *
 * Initial Author: Carlos López (the_spide21@yahoo.com)
 *
 * Author: 
 */

var theUILang =
{
 Downloads			: "Descargas",
 Connection			: "Conexión",
 BitTorrent			: "BitTorrent",
 Advanced			: "Avanzada",
 User_Interface 		: "Interfaz de usuario",
 Confirm_del_torr		: "Confirmar al borrar Torrent(s)",
 Update_GUI_every		: "Actualizar GUI cada",
 ms				: "ms",
 Alt_list_bckgnd		: "Alternar color de fondo en la lista",
 Show_cat_start 		: "Mostrar categorías al iniciar",
 Show_det_start 		: "Mostrar detalles al iniciar",
 Dnt_start_down_auto		: "No iniciar descarga automáticamente",
 Listening_Port 		: "Puerto escucha",
 Port_f_incom_conns		: "Puerto a usar para conexiones entrantes",
 Rnd_port_torr_start		: "Seleccionar un puerto aleatoreo cada vez que inicie rTorrent",
 Type				: "Tipo",
 Bandwidth_Limiting		: "Límite Global de Ancho de Banda",
 Global_max_upl 		: "Vel. máxima de subida",
 unlimited			: "Sin límite",
 Glob_max_downl 		: "Vel. máxima de bajada ",
 Add_bittor_featrs		: "Caraterísticas Adicionales BitTorrent ",
 En_DHT_ntw			: "Activar Red DHT",
 Peer_exch			: "Activar intercambio de pares",
 Ip_report_track		: "IP/Nombre de Host a reportar al tracker",
 Disabled			: "Deshabilitado",
 Enabled			: "Activo",
 ruTorrent_settings		: "Preferencias",
 Doesnt_support 		: "La interfaz ruTorrent no es compatible con tu navegador.",
 Name				: "Nombre",
 Status 			: "Estado",
 Size				: "Tamaño",
 Done				: "Finalizado",
 Downloaded			: "Descargado",
 Uploaded			: "Subido",
 Ratio				: "Ratio",
 DL				: "De",
 UL				: "Su",
 ETA				: "ETA",
 Label				: "Etiqueta",
 Peers				: "Clientes",
 Seeds				: "Semillas",
 Remaining			: "Restante",
 Priority			: "Prioridad",
 Not_torrent_file		: "El archivo debe ser un torrent válido.",
 Pausing			: "Pausando",
 Seeding			: "Compartiendo",
 Downloading			: "Descargando",
 Checking			: "Comprobando",
 Error				: "Error",
 Queued 			: "En cola",
 Finished			: "Completado",
 Stopped			: "Detenido",
 Request_timed_out		: "La petición a rTorrent se ha excedido de tiempo.",
 Start				: "Iniciar",
 Pause				: "Pausar",
 Stop				: "Detener",
 Force_recheck			: "Forzar comprobación",
 New_label			: "Nueva etiqueta...",
 Remove_label			: "Quitar etiqueta",
 Labels 			: "Etiqueta",
 Remove 			: "Eliminar",
 Delete_data			: "Eliminar Datos",
 Remove_and			: "Eliminar y ...",
 Details			: "Detalles...",
 Properties			: "Propiedades...",
 of				: "de", //this two creates line
 connected			: "conectado(s)", //  XX of YY connected
 High_priority			: "Alta",
 Normal_priority		: "Normal",
 Low_priority			: "Baja",
 Dont_download			: "No descargar",
 Files				: "Archivos",
 Logger 			: "Registro",
 s				: "s", // part of "KB/s"
 bytes				: "bytes",
 KB				: "KiB",
 MB				: "MiB",
 GB				: "GiB",
 TB				: "TiB",
 PB				: "PiB",
 Loading			: "Cargando...",
 Torrent_file			: "Archivo Torrent",
 Torrent_URL			: "URL del Torrent",
 Torrent_properties		: "Propiedades del Torrent",
 Trackers			: "Trackers",
 Bandwidth_sett 		: "Preferencias de Ancho de Banda",
 Number_ul_slots		: "Números de puestos de subida",
 Peer_ex			: "Intercambio de pares",
 Enter_label_prom		: "Introduzca la nueva etiqueta para los torrents seleccionados",
 Remove_torrents		: "Eliminar Torrent(s)",
 Rem_torrents_prompt		: "?Desea borrar los torrents seleccionados?",
 All				: "Todos",
 Active 			: "Activos",
 Inactive			: "Inactivos",
 No_label			: "Sin Etiqueta",
 Transfer			: "Transferencia",
 Time_el			: "Transcurrido",
 Share_ratio			: "Ratio",
 Down_speed			: "Vel. de bajada",
 Ul_speed			: "Vel. de subida",
 Wasted 			: "Desperdiciado",
 Tracker			: "Tracker",
 Track_URL			: "URL del Tracker",
 Track_status			: "Estado",
 Created_on			: "Creado el",
 Save_as			: "Archivo",
 Comment			: "Comentario",
 add_button			: "Agregar archivo",
 add_url			: "Agregar URL",
 ok				: "OK",
 Cancel 			: "Cancelar",
 mnu_add			: "Agregar Torrent",
 mnu_remove			: "Eliminar",
 mnu_start			: "Iniciar",
 mnu_pause			: "Pausa",
 mnu_stop			: "Detener",
 mnu_rss			: "Descargador RSS",
 mnu_settings			: "Preferencias",
 mnu_search			: "Búsqueda",
 mnu_lang			: "Idioma",
 torrent_add			: "Agregar Torrent",
 time_w 			: "S ", /*for x weeks*/
 time_d 			: "d ", /*for x days remaining*/
 time_h 			: "h ", /*for x hours remaining*/
 time_m 			: "m ", /*for x minutes remaining*/
 time_s 			: "s ", /*for x seconds remaining*/
 Base_directory 		: "Directorio",
 Number_Peers_min		: "Número mínimo de peers",
 Number_Peers_max		: "Número máximo de peers",
 Tracker_Numwant		: "Número deseado de peers",
 Number_Peers_For_Seeds_min	: "Número mínimo de peers para seedear",
 Number_Peers_For_Seeds_max	: "Número máximo de peers para seedear",
 Enable_port_open		: "Abrir puerto escucha",
 dht_port			: "Puerto UDP para usar con DHT",
 Other_Limiting 		: "Otras limitaciones",
 Number_dl_slots		: "Número de descargas",
 Glob_max_memory		: "Uso máximo de memoria",
 Glob_max_files 		: "Número máximo de archivos abiertos",
 Glob_max_http			: "Número máximo de conexiones http abiertas",
 Other_sett			: "Otros",
 Directory_For_Dl		: "Carpeta por defecto para descargas",
 Check_hash			: "Comprobar hash una vez finalizado",
 Hash				: "Hash",
 DisableTracker 		: "Deshabilitado",
 EnableTracker			: "Habilitado",
 ClientVersion			: "Cliente",
 Flags				: "Flags",
 ReqTimeout			: "Tiempo de espera agotado",
 GetTrackerMessage		: "Recibir mensajes del tracker",
 Help				: "Ayuda",
 Speed				: "Velocidad",
 Dont_add_tname 		: "No agregar el nombre del torrent a la ruta",
 Free_Disk_Space		: "Espacio libre en disco",
 badXMLRPCVersion		: "rTorrent fué compilado con una versión incorrecta de xmlrpc-c, sin soporte i8. La versión debe ser >= 1.11. Algunas funcionalidades no estarán disponibles.",
 badLinkTorTorrent		: "Sin conexión a rTorrent. Compruebe si se encuentra ejecutado. Verifique $scgi_port y $scgi_host en config.php y scgi_port en el archivo de configuración de rTorrent.",
 badUploadsPath 		: "El usuario del Webserver no tiene derechos de lectura/escritura/ejecución en el directorio de torrents. No puede agregar torrents via ruTorrent.",
 badSettingsPath		: "El usuario del Webserver no tiene derechos de lectura/escritura/ejecución en el directorio de configuración. La configuración no puede ser guardada.",
 mnu_help			: "Ayuda",
 badUploadsPath2		: "El usuario rTorrent debe tener acceso de lectura/escritura en la carpeta de torrents. No puede agregar torrents via ruTorrent.",
 View				: "Ver",
 AsList 			: "Lista",
 AsTree 			: "Arbol",
 Group				: "Grupo",
 SuperSeed			: "Super-seed",
 badTestPath			: "El usuario rTorrent debe poder leer/ejecutar el archivo ./test.sh",
 badSettingsPath2		: "El usuario rTorrent debe poder leer/escribir/ejecutar la carpeta de configuración.",
 scrapeDownloaded		: "Descargado",
 Total				: "Total",
 PCRENotFound			: "Módulo PHP PCRE no está instalado. ruTorrent no funcionará.",
 addTorrentSuccess		: "Se agregó el torrent con éxito.",
 addTorrentFailed		: "Fallo al agregar el torrent.",
 pnlState			: "Estado",
 newLabel			: "Nueva etiqueta",
 enterLabel			: "Etiqueta",
 UIEffects			: "Mostrar efectos en los elemontos de la interfaz",
 Plugins			: "Plugins",
 plgName			: "Nombre",
 plgStatus			: "Estado",
 plgLoaded			: "Cargado",
 plgDisabled			: "Sin cargar",
 plgVersion			: "Version",
 plgAuthor			: "Autor",
 plgDescr			: "Descripción",
 mnu_go 			: "Ir",
 pluginCantStart		: "El Plugin no pudo iniciarse.",
 doFastResume			: "Resumido rápido",
 innerSearch			: "Torrents locales",
 removeTeg			: "Remover tag",
 errMustBeInSomeHost		: "ruTorrent y rTorrent deben estar instalados en el mismo servidor. El Plugin no funcionará.",
 warnMustBeInSomeHost		: "ruTorrent y rTorrent deben estar instalados en el mismo servidor. Algunas funcionalidades no estarán disponibles.",
 plgShutdown			: "Unload",
 limit				: "Límite",
 speedList			: "Speed Popup List (separado por comas)",
 ClearButton			: "Borrar",
 dontShowTimeouts		: "Ignorar mensajes de timeout",
 fullTableRender		: "Mostrar tablas grandes",
 showScrollTables		: "Mostrar contenidos mientras se desplaza",
 idNotFound			: "rTorrent no puede acceder al 'id' del programa. Algunas funcionalidades no estarán disponibles.",
 gzipNotFound			: "El Webserver no puede acceder al programa 'gzip'. ruTorrent no funcionará.",
 cantObtainUser 		: "ruTorrent cannot determine the UID of rTorrent user. Algunas funcionalidades no estarán disponibles.",
 retryOnErrorTitle		: "Si rTorrent no está disponible, reintentar en",
 retryOnErrorList		: { 0: "No reintentar", 30: "30 sec", 60: "1 min", 120: "2 min", 300: "5 min", 900: "15 min" },
 statNotFound			: "rTorrent no puede acceder al programa 'stat'. Algunas funcionalidades no estarán disponibles.",
 statNotFoundW			: "El Webserver no puede acceder al programa 'stat'. Algunas funcionalidades no estarán disponibles.",
 badrTorrentVersion		: "El Plugin requiere rTorrent versión >=",
 badPHPVersion			: "El Plugin requiere PHP versión >=",
 rTorrentExternalNotFoundError	: "El Plugin no funcionará. rTorrent no puede acceder al programa externo",
 rTorrentExternalNotFoundWarning: "Algunas funcionalidades no estarán disponibles. rTorrent no puede acceder al programa externo",
 webExternalNotFoundError	: "El Plugin no funcionará. El Webserver no puede acceder al programa externo",
 webExternalNotFoundWarning	: "Algunas funcionalidades no estarán disponibles. El Webserver no puede acceder al programa externo",
 rTorrentBadScriptPath		: "El Plugin no funcionará. rTorrent debe poder leer executar el archivo",
 rTorrentBadPHPScriptPath	: "El Plugin no funcionará. rTorrent no puede leer el archivo",
 dependenceError		: "El Plugin no funcionará. Requiere el plugin(s)",
 peerAdd			: "Agregar Peer...",
 peerBan			: "Ban",
 peerKick			: "Patear",
 peerSnub			: "Snub",
 peerDetails			: "Detalless",
 peerUnsnub			: "Unsnub",
 peerAddLabel			: "IP/Hostname[:puerto]",
 noTorrentList			: "La lista de Torrents no está disponible, no se puede conectar con rTorrent.",
 yes				: "si",
 no				: "no",
 DateFormat			: "Formato de Fecha",
 DLStrategy			: "Estrategia de descarga",
 prioritizeFirst		: "Primer Chunk primero",
 prioritizeLast 		: "Ultimo Chunk primero",
 prioritizeNormal		: "Normal",
 updateTracker			: "Actualizar Trackers",
 scrapeUpdate			: "Actualizado",
 trkInterval			: "Intervalo",
 logAutoSwitch			: "Autoswitch to 'Log' tab",
 showLabelSize			: "Show label size",
 phpParameterUnavailable	: "La directiva PHP register_argc_argv figura como OFF. Cámbiela a ON, de otra manera algunos plugins no funcionarán.",
 addTorrentFailedURL		: "Fallo al agregar torrent. No se encuentra la URL.",
 addTorrentFailedFile		: "Fallo al agregar torrent. El contenido no es un torrent válido.",
 addTorrentFailedDirectory	: "Fallo al agregar torrent. Directorio de descarga incorrecto.",
 plgLaunch			: "Lanzar",
 plgLocked			: "Obligatorio",
 phpExtensionNotFoundWarning	: "Algunas funcionalidades no estarán disponibles. Debe tener PHP instalado",
 phpExtensionNotFoundError	: "El Plugin no funcionará. Debe tener PHP instalado",
 trkPrivate			: "Privado",
 dontSet			: "No marcar",
 webBadSessionError		: "El Plugin no funcionará. El Webserver debe poder ejecutar dentro de la carpeta de sesión",
 webBadSessionWarning		: "Algunas funcionalidades no estarán disponibles. El Webserver debe poder ejecutar dentro de la carpeta de sesión",
 Developers			: "Developers",
 Check_new_version		: "Comprobar versiones nuevas",
 here				: "aqui",
 Num_No 			: "Nº", // This means "Number". To be used as header for number count, e.g.: throttle/ratio plugin
 This_screen			: "Esta pantalla",
 About_program			: "Acerca de ruTorrent",
 Toggle_menu			: "Alternar menu",
 Toggle_details 		: "Alternar detalles",
 Toggle_categories		: "Alternar categorias",
 Delete_current_torrents	: "Borrar torrent(s) actuales",
 Select_all			: "Seleccionar todo",
 Deselect_all			: "Deseleccionar todo",
 General			: "General",
 showSpeedInTitle		: "Mostrar velocidad en el título",
 badTempPath 			: "El usuario del servidor web no tiene permisos de lectura/escritura/ejecución al directorio tmp. ruTorrent no funcionará.",
 badTempPath2			: "El usuario de rTorrent debe tener permisos de lectura/escritura/ejecución al directorio tmp. ruTorrent no funcionará.",
 doRandomizeHash		: "Randomize info hashes for cross-seeding",
 Recreate_files 		: "Queue files recreation",
 Address			: "Address",
 PeerDL 			: "Peer DL",
 PeerDownloaded 		: "Peer Downloaded",
 Save_path			: "Save path",
 registerMagnet			: "Try to register magnet protocol handler at start",
 linkTorTorrentRestored		: "Connection to rTorrent established.",
 removeAllTegs			: "Remove all tags"
};

==> rutorrent-4.3.6.tar.gz: ruTorrent-4.3.6/lang/es.js <==
﻿/*
 * Spanish language file.
 *
 * Initial Author: Carlos López (the_spide21@yahoo.com)
 *
 * Author: 
 */

var theUILang =
{
 General			: "General",
 Downloads			: "Descargas",
 Connection			: "Conexión",
 BitTorrent			: "BitTorrent",
 Format			: "Format",
 Advanced			: "Avanzada",
 User_Interface			: "Interfaz de usuario",
 Confirm_del_torr		: "Confirmar al borrar Torrent(s)",
 Update_GUI_every		: "Actualizar GUI cada",
 ms				: "ms",
 Alt_list_bckgnd		: "Alternar color de fondo en la lista",
 Show_cat_start			: "Mostrar categorías al iniciar",
 Show_det_start			: "Mostrar detalles al iniciar",
 KeepSearches			: "Keep searches",
 KeepSelectedTab			: "Keep selected tab",
 KeepSelectedLabels		: "Keep selected labels",
 Dnt_start_down_auto		: "No iniciar descarga automáticamente",
 Listening_Port			: "Puerto escucha",
 Port_f_incom_conns		: "Puerto a usar para conexiones entrantes",
 Rnd_port_torr_start		: "Seleccionar un puerto aleatoreo cada vez que inicie rTorrent",
 Type				: "Tipo",
 Bandwidth_Limiting		: "Límite Global de Ancho de Banda",
 Global_max_upl			: "Vel. máxima de subida",
 unlimited			: "Sin límite",
 Glob_max_downl			: "Vel. máxima de bajada",
 Add_bittor_featrs		: "Caraterísticas Adicionales BitTorrent",
 En_DHT_ntw			: "Activar Red DHT",
 Peer_exch			: "Activar intercambio de pares",
 Ip_report_track		: "IP/Nombre de Host a reportar al tracker",
 Disabled			: "Deshabilitado",
 Enabled			: "Activo",
 ruTorrent_settings		: "Preferencias",
 Doesnt_support			: "La interfaz ruTorrent no es compatible con tu navegador.",
 Name				: "Nombre",
 Status				: "Estado",
 Size				: "Tamaño",
 Done				: "Finalizado",
 Downloaded			: "Descargado",
 Uploaded			: "Subido",
 Ratio				: "Ratio",
 DL				: "De",
 UL				: "Su",
 ETA				: "ETA",
 Label				: "Etiqueta",
 Peers				: "Clientes",
 Seeds				: "Semillas",
 Remaining			: "Restante",
 Priority			: "Prioridad",
 Not_torrent_file		: "El archivo debe ser un torrent válido.",
 Pausing			: "Pausando",
 Seeding			: "Compartiendo",
 Downloading			: "Descargando",
 Checking			: "Comprobando",
 Error				: "Error",
 Queued				: "En cola",
 Finished			: "Completado",
 Stopped			: "Detenido",
 Request_timed_out		: "La petición a rTorrent se ha excedido de tiempo.",
 Start				: "Iniciar",
 Pause				: "Pausar",
 Stop				: "Detener",
 Force_recheck			: "Forzar comprobación",
 New_label			: "Nueva etiqueta...",
 Remove_label			: "Quitar etiqueta",
 Labels				: "Etiqueta",
 Remove				: "Eliminar",
 Delete_data			: "Eliminar Datos",
 Remove_and			: "Eliminar y",
 Details			: "Detalles...",
 Properties			: "Propiedades...",
 of				: "de", // this two creates line
 connected			: "conectado(s)", // XX of YY connected
 High_priority			: "Alta",
 Normal_priority		: "Normal",
 Low_priority			: "Baja",
 Dont_download			: "No descargar",
 Files				: "Archivos",
 Logger				: "Registro",
 s				: "s", // part of "KB/s"
 bytes				: "bytes",
 KB				: "KiB",
 MB				: "MiB",
 GB				: "GiB",
 TB				: "TiB",
 PB				: "PiB",
 Loading			: "Cargando...",
 Torrent_file			: "Archivo Torrent",
 Torrent_URL			: "URL del Torrent",
 Torrent_properties		: "Propiedades del Torrent",
 Trackers			: "Trackers",
 Bandwidth_sett			: "Preferencias de Ancho de Banda",
 Number_ul_slots		: "Números de puestos de subida",
 Peer_ex			: "Intercambio de pares",
 Enter_label_prom		: "Introduzca la nueva etiqueta para los torrents seleccionados",
 Remove_torrents		: "Eliminar Torrent(s)",
 Rem_torrents_prompt		: "?Desea borrar los torrents seleccionados?",
 All				: "Todos",
 Active				: "Activos",
 Inactive			: "Inactivos",
 No_label			: "Sin Etiqueta",
 Transfer			: "Transferencia",
 Time_el			: "Transcurrido",
 Share_ratio			: "Ratio",
 Down_speed			: "Vel. de bajada",
 Ul_speed			: "Vel. de subida",
 Wasted				: "Desperdiciado",
 Tracker			: "Tracker",
 Track_URL			: "URL del Tracker",
 Track_status			: "Estado",
 Created_on			: "Creado el",
 Save_as			: "Archivo",
 Comment			: "Comentario",
 add_button			: "Agregar archivo",
 add_url			: "Agregar URL",
 ok				: "OK",
 Cancel				: "Cancelar",
 mnu_add			: "Agregar Torrent",
 mnu_remove			: "Eliminar",
 mnu_start			: "Iniciar",
 mnu_pause			: "Pausa",
 mnu_stop			: "Detener",
 mnu_rss			: "Descargador RSS",
 mnu_settings			: "Preferencias",
 mnu_search			: "Búsqueda",
 mnu_lang			: "Idioma",
 torrent_add			: "Agregar Torrent", /*Caption of torrent add box*/
 time_w				: "S ", /*for x weeks*/
 time_d				: "d ", /*for x days remaining*/
 time_h				: "h ", /*for x hours remaining*/
 time_m				: "m ", /*for x minutes remaining*/
 time_s				: "s ", /*for x seconds remaining*/
 Base_directory			: "Directorio",
 Number_Peers_min		: "Número mínimo de peers",
 Number_Peers_max		: "Número máximo de peers",
 Tracker_Numwant		: "Número deseado de peers",
 Number_Peers_For_Seeds_min	: "Número mínimo de peers para seedear",
 Number_Peers_For_Seeds_max	: "Número máximo de peers para seedear",
 Enable_port_open		: "Abrir puerto escucha",
 dht_port			: "Puerto UDP para usar con DHT",
 Other_Limiting			: "Otras limitaciones",
 Number_dl_slots		: "Número de descargas",
 Glob_max_memory		: "Uso máximo de memoria",
 Glob_max_files			: "Número máximo de archivos abiertos",
 Glob_max_http			: "Número máximo de conexiones http abiertas",
 Open_label         : "Abierto",
 Other_sett			: "Otros",
 Directory_For_Dl		: "Carpeta por defecto para descargas",
 Check_hash			: "Comprobar hash una vez finalizado",
 Hash				: "Hash",
 DisableTracker			: "Deshabilitado",
 EnableTracker			: "Habilitado",
 ClientVersion			: "Cliente",
 Flags				: "Flags",
 ReqTimeout			: "Tiempo de espera agotado",
 GetTrackerMessage		: "Recibir mensajes del tracker",
 Help				: "Ayuda",
 Speed				: "Velocidad",
 Dont_add_tname			: "No agregar el nombre del torrent a la ruta",
 Free_Disk_Space		: "Espacio libre en disco",
 badXMLRPCVersion		: "rTorrent fué compilado con una versión incorrecta de xmlrpc-c, sin soporte i8. La versión debe ser >= 1.11. Algunas funcionalidades no estarán disponibles.",
 badLinkTorTorrent		: "Sin conexión a rTorrent. Compruebe si se encuentra ejecutado. Verifique $scgi_port y $scgi_host en config.php y scgi_port en el archivo de configuración de rTorrent.",
 badUploadsPath			: "El usuario del Webserver no tiene derechos de lectura/escritura/ejecución en el directorio de torrents. No puede agregar torrents via ruTorrent.",
 badSettingsPath		: "El usuario del Webserver no tiene derechos de lectura/escritura/ejecución en el directorio de configuración. La configuración no puede ser guardada.",
 mnu_help			: "Ayuda",
 badUploadsPath2		: "El usuario rTorrent debe tener acceso de lectura/escritura en la carpeta de torrents. No puede agregar torrents via ruTorrent.",
 View				: "Ver",
 AsList				: "Lista",
 AsTree				: "Arbol",
 Group				: "Grupo",
 SuperSeed			: "Super-seed",
 badTestPath			: "El usuario rTorrent debe poder leer/ejecutar el archivo ./test.sh",
 badSettingsPath2		: "El usuario rTorrent debe poder leer/escribir/ejecutar la carpeta de configuración.",
 scrapeDownloaded		: "Descargado",
 Total				: "Total",
 PCRENotFound			: "Módulo PHP PCRE no está instalado. ruTorrent no funcionará.",
 addTorrentSuccess		: "Se agregó el torrent con éxito.",
 addTorrentFailed		: "Fallo al agregar el torrent.",
 pnlViews			: "Views",
 NewView			: "New View",
 MoveView			: {base: "Move view", top: "To top", up: "Up", down: "Down", bottom: "To bottom"},
 RenameView			: "Rename view",
 RemoveActiveViews		: "Remove active views",
 SaveCurrentView		: "Save current view",
 showViewPanel			: "Show Views panel",
 showViewLabelSize		: "Show label size in Views panel",
 pnlState			: "Estado",
 newLabel			: "Nueva etiqueta",
 enterLabel			: "Etiqueta",
 UIEffects			: "Mostrar efectos en los elemontos de la interfaz",
 Plugins			: "Plugins",
 plgName			: "Nombre",
 plgStatus			: "Estado",
 plgLoaded			: "Cargado",
 plgDisabled			: "Sin cargar",
 plgVersion			: "Version",
 plgAuthor			: "Autor",
 plgDescr			: "Descripción",
 mnu_go				: "Ir",
 pluginCantStart		: "El Plugin no pudo iniciarse.",
 doFastResume			: "Resumido rápido",
 innerSearch			: "Torrents locales",
 removeTeg			: "Remover tag",
 errMustBeInSomeHost		: "ruTorrent y rTorrent deben estar instalados en el mismo servidor. El Plugin no funcionará.",
 warnMustBeInSomeHost		: "ruTorrent y rTorrent deben estar instalados en el mismo servidor. Algunas funcionalidades no estarán disponibles.",
 plgShutdown			: "Unload",
 limit				: "Límite",
 speedList			: "Speed Popup List (separado por comas)",
 DecimalPlacesSizes		: "Decimal Places of Sizes",
 CatListSizeDecimalPlaces	: "In category list",
 TableSizeDecimalPlaces	: "In tables",
 DetailsSizeDecimalPlaces	: "In general tab",
 OtherSizeDecimalPlaces	: "Other",
 Default	: "Default",
 ClearButton			: "Borrar",
 dontShowTimeouts		: "Ignorar mensajes de timeout",
 fullTableRender		: "Mostrar tablas grandes",
 showScrollTables		: "Mostrar contenidos mientras se desplaza",
 idNotFound			: "rTorrent no puede acceder al 'id' del programa. Algunas funcionalidades no estarán disponibles.",
 gzipNotFound			: "El Webserver no puede acceder al programa 'gzip'. ruTorrent no funcionará.",
 cantObtainUser			: "ruTorrent cannot determine the UID of rTorrent user. Algunas funcionalidades no estarán disponibles.",
 retryOnErrorTitle		: "Si rTorrent no está disponible, reintentar en",
 retryOnErrorList		: { 0: "No reintentar", 30: "30 sec", 60: "1 min", 120: "2 min", 300: "5 min", 900: "15 min" },
 statNotFound			: "rTorrent no puede acceder al programa 'stat'. Algunas funcionalidades no estarán disponibles.",
 statNotFoundW			: "El Webserver no puede acceder al programa 'stat'. Algunas funcionalidades no estarán disponibles.",
 badrTorrentVersion		: "El Plugin requiere rTorrent versión >=",
 badPHPVersion			: "El Plugin requiere PHP versión >=",
 rTorrentExternalNotFoundError	: "El Plugin no funcionará. rTorrent no puede acceder al programa externo",
 rTorrentExternalNotFoundWarning: "Algunas funcionalidades no estarán disponibles. rTorrent no puede acceder al programa externo",
 webExternalNotFoundError	: "El Plugin no funcionará. El Webserver no puede acceder al programa externo",
 webExternalNotFoundWarning	: "Algunas funcionalidades no estarán disponibles. El Webserver no puede acceder al programa externo",
 rTorrentBadScriptPath		: "El Plugin no funcionará. rTorrent debe poder leer executar el archivo",
 rTorrentBadPHPScriptPath	: "El Plugin no funcionará. rTorrent no puede leer el archivo",
 dependenceError		: "El Plugin no funcionará. Requiere el plugin(s)",
 peerAdd			: "Agregar Peer...",
 peerBan			: "Ban",
 peerKick			: "Patear",
 peerSnub			: "Snub",
 peerDetails			: "Detalless",
 peerUnsnub			: "Unsnub",
 peerAddLabel			: "IP/Hostname[:puerto]",
 noTorrentList			: "La lista de Torrents no está disponible, no se puede conectar con rTorrent.",
 yes				: "si",
 no				: "no",
 DateFormat			: "Formato de Fecha",
 DLStrategy			: "Estrategia de descarga",
 prioritizeFirst		: "Primer Chunk primero",
 prioritizeLast			: "Ultimo Chunk primero",
 prioritizeNormal		: "Normal",
 updateTracker			: "Actualizar Trackers",
 scrapeUpdate			: "Actualizado",
 trkInterval			: "Intervalo",
 logAutoSwitch			: "Autoswitch to 'Log' tab",
 showStateLabelSize		: "Show label size in State panel",
 showLabelSize			: "Show label size in Labels panel",
 showSearchLabelSize		: "Show label size in Search panel",
 showCustomLabelTree		: "Show label path tree",
 labelSizeRightAlign		: "Right align size in category list",
 showEmptyPathLabel		: "Show empty path labels",
 showLabelTextOverflow	: "Allow overflow of label text",
 showOpenStatus		: "Show open status in status bar",
 requiresAtLeastRtorrent		: "Requires rTorrent >= {version}", // ... v0.9.7
 phpParameterUnavailable	: "La directiva PHP register_argc_argv figura como OFF. Cámbiela a ON, de otra manera algunos plugins no funcionarán.",
 addTorrentFailedURL		: "Fallo al agregar torrent. No se encuentra la URL.",
 addTorrentFailedFile		: "Fallo al agregar torrent. El contenido no es un torrent válido.",
 addTorrentFailedDirectory	: "Fallo al agregar torrent. Directorio de descarga incorrecto.",
 plgLaunch			: "Lanzar",
 plgLocked			: "Obligatorio",
 phpExtensionNotFoundWarning	: "Algunas funcionalidades no estarán disponibles. Debe tener PHP instalado",
 phpExtensionNotFoundError	: "El Plugin no funcionará. Debe tener PHP instalado",
 trkPrivate			: "Privado",
 dontSet			: "No marcar",
 webBadSessionError		: "El Plugin no funcionará. El Webserver debe poder ejecutar dentro de la carpeta de sesión",
 webBadSessionWarning		: "Algunas funcionalidades no estarán disponibles. El Webserver debe poder ejecutar dentro de la carpeta de sesión",
 Developers			: "Developers",
 Check_new_version		: "Comprobar versiones nuevas",
 here				: "aqui",
 Num_No				: "Nº", // This means "Number". To be used as header for number count, e.g.: throttle/ratio plugin
 This_screen			: "Esta pantalla",
 About_program			: "Acerca de ruTorrent",
 Toggle_menu			: "Alternar menu",
 Toggle_details			: "Alternar detalles",
 Toggle_categories		: "Alternar categorias",
 Delete_current_torrents	: "Borrar torrent(s) actuales",
 Select_all			: "Seleccionar todo",
 Deselect_all			: "Deseleccionar todo",
 showSpeedInTitle		: "Mostrar velocidad en el título",
 speedGraphDuration		: "Duration of speed graph",
 speedGraphDurationOptions		: {600: "10 min", 1800: "30 min", 3600: "1 hr", 10800: "3 hrs"},
 badTempPath			: "El usuario del servidor web no tiene permisos de lectura/escritura/ejecución al directorio tmp. ruTorrent no funcionará.",
 badTempPath2			: "El usuario de rTorrent debe tener permisos de lectura/escritura/ejecución al directorio tmp. ruTorrent no funcionará.",
 doRandomizeHash		: "Randomize info hashes for cross-seeding",
 Recreate_files			: "Queue Files Recreation",
 Address			: "Address",
 PeerDL				: "Peer DL",
 PeerDownloaded			: "Peer Downloaded",
 Save_path			: "Save path",
 registerMagnet			: "Try to register magnet protocol handler at start",
 linkTorTorrentRestored		: "Connection to rTorrent established.",
 removeAllTegs			: "Remove all tags",
 Torrents			: "Torrent(s)",
 copyToClipboardFailed		: "The copy function isn't working in your browser.\nPlease copy this content manually:\n\n",
 copyToClipboardSuccess		: "Copied to clipboard successfully!"
};
